@@ -54,7 +54,7 @@ setMethod(f = "initialize",
 
                   # wild type or given flux distribution
                   if (is.null(wtflux)) {
-                      tmp <- sybil:::.generateWT(model, ...)
+                      tmp <- .generateWT(model, ...)
                       wtsol <- tmp$fluxes[tmp$fldind]
                   }
                   else {
@@ -104,7 +104,7 @@ setMethod(f = "initialize",
                   # row and column names for the problem object
                   if (isTRUE(useNames)) {
                       if (is.null(cnames)) {
-                          colNames <- sybil:::.makeLPcompatible(react_id(model),
+                          colNames <- .makeLPcompatible(react_id(model),
                                                                 prefix = "x")
                       }
                       else {
@@ -114,7 +114,7 @@ setMethod(f = "initialize",
                       }
 
                       if (is.null(rnames)) {
-                          rowNames <- sybil:::.makeLPcompatible(met_id(model),
+                          rowNames <- .makeLPcompatible(met_id(model),
                                                                 prefix = "r")
                       }
                       else {
@@ -124,7 +124,7 @@ setMethod(f = "initialize",
                       }
 
                       if (is.null(pname)) {
-                          probName <- sybil:::.makeLPcompatible(
+                          probName <- .makeLPcompatible(
                               paste("MOMA", mod_id(model), sep = "_"),
                               prefix = "")
                       }
